# add missing see_also relation definitions
see_also_schema = schema.rschema('see_also')

if 'Versionedfile' in schema:
    for ttype in ('Card', 'Blog', 'File', 'Image', 'Link', 'Versionedfile'):
        if not see_also_schema.has_rdef('Versionedfile', ttype):
            add_relation_definition('Versionedfile', 'see_also', ttype)
            
for ttype in ('Card', 'Blog', 'File', 'Image', 'Link'):
    if not see_also_schema.has_rdef('Image', ttype):
        add_relation_definition('Image', 'see_also', ttype)
        



add_relation_definition('Card', 'see_also', 'File')
add_relation_definition('Blog', 'see_also', 'File')
add_relation_definition('File', 'see_also', 'File')
add_relation_definition('Card', 'see_also', 'Link')
add_relation_definition('Blog', 'see_also', 'Link')
add_relation_definition('File', 'see_also', 'Link')
add_relation_definition('Link', 'see_also', 'Link')

synchronize_permissions('Blog')
synchronize_permissions('Card')
synchronize_permissions('File')
synchronize_permissions('Link')


rql('SET X see_also Y WHERE X concerns Y')

drop_relation_type('concerns')



"""schema customization for the intranet application

:organization: Logilab
:copyright: 2003-2009 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
:contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
"""
__docformat__ = "restructuredtext en"

from yams.buildobjs import RelationDefinition

try:
    from cubes.card.schema import Card
    from cubes.blog.schema import BlogEntry
    from cubes.file.schema import File, Image
    from cubes.link.schema import Link
    from yams.reader import context
    defined_types = context.defined
except (ImportError, NameError):
    # old-style yams schema will raise NameError on EntityType, RelationType, etc.
    Card = import_erschema('Card')
    BlogEntry = import_erschema('BlogEntry')
    File = import_erschema('File')
    Image = import_erschema('Image')
    Link = import_erschema('Link')

PERMISSIONS = {
        'read':   ('managers', 'users', 'guests',),
        'add':    ('managers', 'users',),
        'delete': ('managers', 'owners',),
        'update': ('managers', 'users', 'owners',),
        }

Card.__permissions__ = PERMISSIONS
BlogEntry.__permissions__ = PERMISSIONS
File.__permissions__ = PERMISSIONS
Image.__permissions__ = PERMISSIONS
Link.__permissions__ = PERMISSIONS

class interested_in(RelationDefinition):
    subject = 'CWUser'
    object = 'Event'


BASETYPES = ('Card', 'BlogEntry', 'File', 'Image', 'Event', 'Link', 'Task', 'Book')
if 'VersionedFile' in defined_types:
    BASETYPES += ('VersionedFile',)

class see_also(RelationDefinition):
    subject = BASETYPES
    object = BASETYPES

class comments(RelationDefinition):
    subject = 'Comment'
    object = BASETYPES

class tags(RelationDefinition):
    subject = 'Tag'
    object = BASETYPES



"""specific view classes for intranet

:organization: Logilab
:copyright: 2008-2009 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
:contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
"""
__docformat__ = "restructuredtext en"

from cubicweb.selectors import implements

from cubes.tag.views import TagsCloudBox

TagsCloudBox.visible = True
TagsCloudBox.__select__ = TagsCloudBox.__select__ & implements('BlogEntry', 'Link', 'Card', 'File', 'Image')



#!/usr/bin/env python
# pylint: disable-msg=W0404,W0622,W0704,W0613,W0152
# Copyright (c) 2003-2004 LOGILAB S.A. (Paris, FRANCE).
# http://www.logilab.fr/ -- mailto:contact@logilab.fr
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
""" Generic Setup script, takes package info from __pkginfo__.py file """

from distutils.core import setup

# import required features
from __pkginfo__ import distname, version, license, short_desc, long_desc, \
     web, author, author_email
# import optional features
try:
    from __pkginfo__ import data_files
except ImportError:
    data_files = None
try:
    from __pkginfo__ import include_dirs
except ImportError:
    include_dirs = []

def install(**kwargs):
    """setup entry point"""
    #kwargs['distname'] = modname
    return setup(name=distname,
                 version=version,
                 license =license,
                 description=short_desc,
                 long_description=long_desc,
                 author=author,
                 author_email=author_email,
                 url=web,
                 data_files=data_files,
                 **kwargs)

if __name__ == '__main__' :
    install()



# pylint: disable-msg=W0622
"""cubicweb-intranet application packaging information"""

modname = 'intranet'
distname = "cubicweb-intranet"

numversion = (1, 0, 0)
version = '.'.join(str(num) for num in numversion)

license = 'LGPL'
copyright = '''Copyright (c) 2003-2010 LOGILAB S.A. (Paris, FRANCE).
http://www.logilab.fr/ -- mailto:contact@logilab.fr'''

author = "Logilab"
author_email = "contact@logilab.fr"

short_desc = "an intranet built on the CubicWeb framework"
long_desc = """
CubicWeb is a semantic web application framework, see http://www.cubicweb.org
"""

web = 'http://cubicweb.org/project/cubicweb-intranet'
ftp = ''

pyversions = ['2.4']

classifiers = [
    'Environment :: Web Environment'
    'Framework :: CubicWeb',
    'Programming Language :: Python',
    'Programming Language :: JavaScript',
    ]

__depends_cubes__ = {'blog': None,
                     'book': None,
                     'card': None,
                     'comment': None,
                     'file': None,
                     'folder': None,
                     'link': None,
                     'tag': None,
                     'task': None,
                     'event': None,
                     }
__depends__ = {'cubicweb': '>= 3.6.0'}
for key, value in __depends_cubes__.items():
    __depends__['cubicweb-'+key] = value
__use__ = tuple(__depends_cubes__)
__recommend__ = ()

# packaging ###

from os import listdir
from os.path import join, isdir

TEMPLATES_DIR = join('share', 'cubicweb', 'cubes')
try:
    data_files = [
        [join(TEMPLATES_DIR, 'intranet'),
         [fname for fname in listdir('.')
          if fname.endswith('.py') and fname != 'setup.py']],
        [join(TEMPLATES_DIR, 'intranet', 'data'),
         [join('data', fname) for fname in listdir('data')]],
        [join(TEMPLATES_DIR, 'intranet', 'i18n'),
         [join('i18n', fname) for fname in listdir('i18n')]],
        [join(TEMPLATES_DIR, 'intranet', 'migration'),
         [join('migration', fname) for fname in listdir('migration')]],
        ]
except OSError:
    # we are in an installed directory
    pass
